# -*-coding:utf-8 -*- #

import openpyxl

from BPMInterfaceAutoTest.common import log
from BPMInterfaceAutoTest.common.read_ini import ReadIni
from BPMInterfaceAutoTest.common.read_json import read_json


class ReadExcel:
    def __init__(self):
        self.read_ini = ReadIni()

        self.excel_path = self.read_ini.get_file_path("excel")
        table_name = self.read_ini.get_table_name("table_name")

        self.wb = openpyxl.load_workbook(self.excel_path)
        try:
            self.ws = self.wb[table_name]
        except:
            log.error("工作表名称错误，请到配置文件中检查工作表名称")
            raise KeyError("工作表名称错误，请到配置文件中检查工作表名称")

        case_data_path = self.read_ini.get_file_path("case_data")
        expect_data_path = self.read_ini.get_file_path("expect_data")
        sql_sentence_path = self.read_ini.get_file_path("sql_sentence")

        self.case_data_dict = read_json(case_data_path)
        self.excel_data_dict = read_json(expect_data_path)
        self.sql_sentence_dict = read_json(sql_sentence_path)

    def __get_cell_value(self, column: str, row: int) -> str:
        try:
            value = self.ws[column + str(row)].value

            if value is None:
                return None
            elif value.strip():
                return value.strip()
        except:
            log.error("获取excel数据错误，请检查输入的行号或列号")
            raise KeyError("获取excel数据错误，请检查输入的行号或列号")

    def get_module_name(self, row):
        return self.__get_cell_value('b', row)

    def get_api_name(self, row):
        return self.__get_cell_value('c', row)

    def get_title(self, row):
        return self.__get_cell_value('d', row)

    def get_level(self, row):
        return self.__get_cell_value('f', row)

    def get_method(self, row):
        method = self.__get_cell_value('f', row)

        if method:
            return method.lower()

    def get_url(self, row):
        path = self.__get_cell_value('g', row)

        if path:
            return self.read_ini.get_bpm_host("bpm_host") + path

    def get_mime(self, row):
        mime = self.__get_cell_value('h', row)

        if mime:
            return mime.lower()

    def get_case_data(self, row):
        case_data_key = self.__get_cell_value('i', row)

        if case_data_key:
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            return self.case_data_dict[module_name][api_name][case_data_key]

    def get_expect_data(self, row):
        expect_data_key = self.__get_cell_value('j', row)

        if expect_data_key:
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            return self.excel_data_dict[module_name][api_name][expect_data_key]

    def get_sql_sentence(self, row):
        sql_sentence_key = self.__get_cell_value('k', row)

        if sql_sentence_key:
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            return self.sql_sentence_dict[module_name][api_name][sql_sentence_key]

    def get_sql_sentence_type(self, row):
        sql_sentence_type = self.__get_cell_value('l', row)

        if sql_sentence_type:
            return sql_sentence_type.lower()

    def get_update_key(self, row):
        return self.__get_cell_value('m', row)

    def get_data(self):
        data_list = []

        for row in range(2, self.ws.max_row + 1):
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            title = self.get_title(row)
            level = self.get_level(row)
            method = self.get_method(row)
            url = self.get_url(row)
            mime = self.get_mime(row)
            case_data = self.get_case_data(row)
            expect_data = self.get_expect_data(row)
            sql_sentence = self.get_sql_sentence(row)
            sql_sentence_type = self.get_sql_sentence_type(row)
            update_key = self.get_update_key(row)

            data_list.append(
                [module_name, api_name, title, level, method, url, mime, case_data, expect_data, sql_sentence,
                 sql_sentence_type, update_key])

        return data_list


if __name__ == '__main__':
    read_excel = ReadExcel()
    # print(read_excel._ReadExcel__get_cell_value('b', 3))
    print(read_excel.get_data())
