# -*-coding:utf-8 -*- #

import configparser
import os

from BPMInterfaceAutoTest.common import log


class ReadIni:
    def __init__(self):
        self.data_config_path = os.path.join(os.path.dirname(os.path.dirname(__file__)), "data_config")
        ini_path = os.path.join(self.data_config_path, "config.ini")

        self.conf = configparser.ConfigParser()
        self.conf.read(ini_path, encoding="utf-8")

    def get_file_path(self, key):
        try:
            file_path = os.path.join(self.data_config_path, self.conf.get("file", key))
        except:
            log.error("ini文件中没有找到对应的文件，请检查key是否输入正确或配置文件")
            raise KeyError("ini文件中没有找到对应的文件，请检查key是否输入正确或配置文件")

        if os.path.isfile(file_path):
            return file_path
        else:
            log.error("没有找到文件，请检查文件是否存在或文件名称")
            raise FileNotFoundError("没有找到文件，请检查文件是否存在或文件名称")

    def get_table_name(self, key):
        try:
            return self.conf.get("table_name", key)
        except:
            log.error("ini文件中没有找到对应的表名，请检查key是否输入正确或配置文件")
            raise KeyError("ini文件中没有找到对应的表名，请检查key是否输入正确或配置文件")

    def get_bpm_host(self, key):
        try:
            return self.conf.get("host", key)
        except:
            log.error("ini文件中没有找到对应的域名，请检查key是否输入正确或配置文件")
            raise KeyError("ini文件中没有找到对应的域名，请检查key是否输入正确或配置文件")

    def get_sql_conn_msg(self, key):
        try:
            return self.conf.get("sql", key)
        except:
            log.error("ini文件中没有找到对应的数据库链接信息，请检查key是否输入正确或配置文件")
            raise KeyError("ini文件中没有找到对应的数据库链接信息，请检查key是否输入正确或配置文件")


if __name__ == '__main__':
    read_ini = ReadIni()
    print(read_ini.get_file_path("excel"))
    print(read_ini.get_table_name("table_name"))
    print(read_ini.get_bpm_host("bpm_host"))
    print(read_ini.get_sql_conn_msg("sql_host"))
