# -*-coding:utf-8 -*- #
import base64

import requests

from BPMInterfaceAutoTest.common import log
from BPMInterfaceAutoTest.common.read_excel import ReadExcel
from BPMInterfaceAutoTest.common.read_ini import ReadIni


class RequestMethods:
    def __init__(self):
        login_url = ReadIni().get_bpm_host("bpm_host") + "/auth"
        login_data = {"username": "admin", "password": base64.b64encode("123456".encode()).decode()}

        self.bpm_session = requests.sessions.Session()

        login_res = self.bpm_session.post(url=login_url, json=login_data)
        self.bpm_session.headers.update({"Authorization": "Bearer " + login_res.json()["token"]})

    def request_all(self, method, url, case_data=None, mime=None):
        if mime == "json" or mime == "application/json":
            return self.bpm_session.request(method=method, url=url, json=case_data)
        elif mime == "x-www-form-urlencoded" or mime == "application/x-www-form-urlencoded":
            return self.bpm_session.request(method=method, url=url, data=case_data)
        elif mime == "files" or mime == "multipart/form-data":
            return self.bpm_session.request(method=method, url=url, files=case_data)
        elif mime == "query" or mime == "param":
            return self.bpm_session.request(method=method, url=url, params=case_data)
        elif mime is None:
            return self.bpm_session.request(method=method, url=url)
        elif mime == "query|body" or mime == "body|query" or mime == "body|params" or mime == "params|body":
            return self.bpm_session.request(method=method, url=url, params=case_data["query"], json=case_data["body"])
        else:
            log.error("找不到传入的媒体类型，请检查excel文件，若有需要请自行封装")
            raise NameError("找不到传入的媒体类型，请检查excel文件，若有需要请自行封装")


if __name__ == '__main__':
    request_methods = RequestMethods()

    case_data = ReadExcel().get_data()[7]
    res = request_methods.request_all(method=case_data[0], url=case_data[1], mime=case_data[2], case_data=case_data[3])

    # print(res.text)
